{% extends "spirit/_base.html" %}

{% load i18n %}

{% block title %}{% trans "Publish comment" %}{% endblock %}

{% block content %}

    <h1 class="headline">{% trans "Publishing comment on" %} "{{ topic.title }}"</h1>
    
    <form action="." method="post" class="js-reply">
        {% csrf_token %}
        {% include "spirit/_form.html" %}

        <div class="container">
            {% include "spirit/comment/_editor.html" %}

            <input class="button reply-button" type="submit" value="{% trans "Publish" %}" />
        </div>
    </form>

{% endblock %}