{% extends "spirit/_base.html" %}

{% load spirit_tags i18n %}

{% block title %}{% trans "Latest active topics" %}{% endblock %}

{% block content %}

    {% include "spirit/topic/_top_bar.html" with category=None categories=categories %}

    {% include "spirit/topic/_render_list.html" %}

    {% render_paginator topics %}

{% endblock %}
